function force_plate_visualize(force, moment)

persistent figureHandle forceArrowHandle momentArrowHandle placeHgTransform forceScale momentScale momentVectorScale axisHandle;


if isempty(figureHandle) || ~ishandle(figureHandle)
    
    % set up the figure
    
    figureHandle = figure('renderer', 'opengl');
    axisHandle = gca;
    view(30,30);
    axis equal;
    set(gca, 'xlimMode', 'manual');
    set(gca, 'ylimMode', 'manual');
    set(gca, 'zlimMode', 'manual');
    hold on;
    
    % size of 3d axis space
    maxOnEachSide = 50;
    set(gca, 'xlim', [-maxOnEachSide maxOnEachSide]);
    set(gca, 'ylim',[-maxOnEachSide maxOnEachSide] );
    set(gca, 'zlim', [-maxOnEachSide maxOnEachSide]);
    
    
    set(gca, 'xticklabel',[])
    set(gca, 'yticklabel',[])
    xlabel('X');
    ylabel('Y');
    
    forceArrowHandle=[];
    momentArrowHandle = [];
    forcePlateHandle  =[];
    
    cylinderHandle =[];
    
    % force platform and its homogeneous transform
    forcePlateHandle = cube([-20 -20 -3] ,[40 40 6], 1);
    set(forcePlateHandle, 'facecolor',[0 0.4 0.4]);
    
    placeHgTransform = hgtransform('Parent', gca);
    set(forcePlateHandle,'Parent',placeHgTransform)
    
    % place transprent ground
    groundhandle = patch([-maxOnEachSide -maxOnEachSide maxOnEachSide maxOnEachSide -maxOnEachSide], [-maxOnEachSide maxOnEachSide maxOnEachSide -maxOnEachSide -maxOnEachSide], [0 0 0 0 0], 'facealpha' ,0.2);
    
    set(groundhandle, 'FaceVertexAlphaData',0.2);
    set(groundhandle, 'FaceAlpha','flat');
    set(groundhandle, 'FaceColor',[0.6 0.2 0]);
    
    
    momentScale = 1/ 2000;
    forceScale = 1/ 20;
    momentVectorScale = 1 /30;    
    
end;

arrowStart = [0 0 0];

lastForceArrowHandle = forceArrowHandle;
lastMomentArrowHandle = momentArrowHandle;

% force arrow
forceArrowEnd = force' * forceScale;
forceArrowOrientation = forceArrowEnd - arrowStart;
forceArrowHandle = quiver3(axisHandle, arrowStart(1),arrowStart(2),arrowStart(3), forceArrowOrientation(1),forceArrowOrientation(2),forceArrowOrientation(3),'filled', 'linewidth',2 ,'color',[1 0 0]);

% moment arrow

rotationMatrix = makehgtform('xrotate', moment(1) * momentScale, 'yrotate', moment(2) * momentScale,'zrotate', moment(3) * momentScale);

% moment size is shown by rotating a vector (originally in +z) and size
% modulatd by moment size
momentArrowEnd = rotationMatrix * [0 0 norm(moment * momentVectorScale, 'fro') 1]';

momentArrowOrientation = momentArrowEnd(1:3)' - arrowStart;
momentArrowHandle = quiver3(axisHandle, arrowStart(1),arrowStart(2),arrowStart(3), momentArrowOrientation(1),momentArrowOrientation(2),momentArrowOrientation(3),'filled', 'linewidth',2 ,'color',[0 0 1]);


% force platform tilt
set(placeHgTransform,'Matrix',rotationMatrix);


delete(lastForceArrowHandle);
delete(lastMomentArrowHandle);

drawnow;


end