function mr_detect_bad_channels(doReset)
% detects noisy (bad) channels and puts their indices in mr.eeg.badChannels field. It uses abs. correlation between each channel and all other channels and if this value falls below a threshold in the last ~200 EEG frames, the channel is flagged as being noisy. 
global mr;

% for implementing some hysterisis. A channel is not bad only if it has
% been good several times in a row
persistent numberOfRunsOnWhichChannelHasBeenGood numberOframesReceivedLastRun

if nargin>0 && doReset
    numberOframesReceivedLastRun = [];
end;
    

% run it every second one time only
if ~isempty(numberOframesReceivedLastRun) && (mr.numberOfFramesReceived - numberOframesReceivedLastRun < mr.samplingRate/2) % run every half seconds
    return;
else
    numberOframesReceivedLastRun = mr.numberOfFramesReceived;
end;


numberOfRunsToQualityAChannelToBeUsed = 5;
badChannelCorrelationThreshold = 0.4;

if isempty(numberOfRunsOnWhichChannelHasBeenGood)
    numberOfRunsOnWhichChannelHasBeenGood = numberOfRunsToQualityAChannelToBeUsed * ones(1,length(mr.eeg.channelNumbers));
end;

numberOfFramesInBlockUsedInCorrelation = round(mr.samplingRate/2);

if mr.numberOfFramesInAccumulatedData < numberOfFramesInBlockUsedInCorrelation
    mr.eeg.badChannels = [];
    return;
end;

channelActivityBlockFrames = 1 + mr.numberOfFramesInAccumulatedData-numberOfFramesInBlockUsedInCorrelation:mr.numberOfFramesInAccumulatedData;

% perform re-referencing 
if mr.eeg.reference_is_included
    % means that the reference channel index is relative to channel subset indices
    channelActivityBlock = channel_subset_and_re_reference_to_included_reference(mr, channelActivityBlockFrames);
else
    % means that the reference channel index is relative to original
    % (all) accumulated channel data
    channelActivityBlock = channel_subset_and_re_reference_to_non_included_reference(mr, channelActivityBlockFrames);
end;

for i=1:size(channelActivityBlock,1)
    channelActivityBlock(i,:) = channelActivityBlock(i,:) - mean(channelActivityBlock(i,:));
end;

absoluteCorrelationWithOtherChannels = abs(corrcoef(channelActivityBlock'));
% remove 1s on the diagonal
absoluteCorrelationWithOtherChannels = absoluteCorrelationWithOtherChannels - diag(diag(absoluteCorrelationWithOtherChannels));
maxAbsCorrelationWithOtherChannels = max(absoluteCorrelationWithOtherChannels);

badChannelsInThisRun = maxAbsCorrelationWithOtherChannels < badChannelCorrelationThreshold;

% increment for all channels but zero it for for bad channels
numberOfRunsOnWhichChannelHasBeenGood = numberOfRunsOnWhichChannelHasBeenGood + 1;
numberOfRunsOnWhichChannelHasBeenGood(badChannelsInThisRun) = 0;

mr.eeg.badChannels = find(numberOfRunsOnWhichChannelHasBeenGood < numberOfRunsToQualityAChannelToBeUsed);
