function mr_update_ica
% updates ICA decomposition matrix to exclude noisy channels. It creates a
% new ICA matrix in mr.eeg.activeIcaUnmix field based on the original
% matrix in mr.eeg.originalIcaUnmix field. (same size but with zeros for
% noisy channels and changed values for other channels)
global mr;

persistent lastIcaBadChannelList originalIcaMix;

if isempty(originalIcaMix)
    originalIcaMix = pinv(mr.eeg.originalIcaUnmix);
end;

% to check if there has been any change in bad channel list
if ~isempty(setxor(lastIcaBadChannelList, mr.eeg.badChannels))
    newIcaMix = originalIcaMix;
    newIcaMix(mr.eeg.badChannels,:) = [];
    newIcaUnMix = pinv(newIcaMix);
    
    % the new unmixing matrix has zeros for bad channels and is the same
    % size.
    mr.eeg.activeIcaUnmix = zeros(size(originalIcaMix));
    goodChannels = setdiff(1:length(mr.eeg.channelNumbers), mr.eeg.badChannels); % channels that are not noisy (detected as 'bad' by mr_detect_bad_channels function).
    mr.eeg.activeIcaUnmix(:, goodChannels) = newIcaUnMix; 
    
    lastIcaBadChannelList = mr.eeg.badChannels;
end;
