function mr_im_activity_on_grid(doReset)

global mr

persistent figureHandle axisHandle icIds  icCircularBuffer lastCalculatedLatency numberOfFrequencies frequencies;
persistent numberOfFramesInSum sumPower sumPower2  wavelet maxWaveletLength powerAtFreqId imTemplate barHandle ;

if nargin<1
    doReset = false;
end;


if doReset || isempty(figureHandle) || ~ishandle(figureHandle)
    
    numberOfFramesInSum = 0;
    sumPower = 0;
    sumPower2 = 0;
    
    figureHandle = figure;
    axisHandle = gca;
    set(gcf,'Renderer' ,'opengl');
    
    % frequency band and wavelets
    freqs = [3 100];
    numberOfFrequencies = 40;
    frequencies = logspace(log10(freqs(1)), log10(freqs(2)), numberOfFrequencies);
    [wavelet,cycles,freqresol,timeresol] = dftfilt3(frequencies, 3, mr.samplingRate);
    
    maxWaveletLength = -inf;
    for i=1:length(wavelet)
        maxWaveletLength = max([maxWaveletLength length(wavelet{i})]);
    end;
    
    lastCalculatedLatency = maxWaveletLength;
    icIds = [1 2 3]; % ID of ics in all ICs for which activity is calculated
    
    % create circular buffers, each for one ic in icIds
    icCircularBuffer = circular_buffer_init(max(maxWaveletLength, round(mr.samplingRate / 2)), numberOfFrequencies);
    
    for i=icIds(2:end)
        icCircularBuffer(i) = circular_buffer_init(max(maxWaveletLength, round(mr.samplingRate / 2)), numberOfFrequencies);
    end;
    
    
    imTemplate = zeros(4, numberOfFrequencies);    
    imTemplate(1, frequencies < 7.5) = 1; % theta
    imTemplate(2, frequencies > 7.5 & frequencies < 12) = 1; % alpha
    imTemplate(3, frequencies > 12 & frequencies < 30) = 1; % beta
    imTemplate(4, frequencies > 30) = 1; % gamma
end;

if mr.numberOfFramesInAccumulatedData > mr.samplingRate*2
    
    % get ids from the last calculated latency minus frames necessary for
    % wavelet multipication
    
    rangeIdsInBuffer = mr_map_frame_range_to_circular_buffer_indices([(lastCalculatedLatency + 1 - maxWaveletLength+1) mr.numberOfFramesReceived], mr.eeg.accumulatedIcActivity);
    
    if min(rangeIdsInBuffer)<1
        return;
    end;
    
    icActivity = mr.eeg.accumulatedIcActivity.buffer(:, rangeIdsInBuffer);

    for icId = icIds
        for waveletNumber = 1:length(wavelet)
            for frame = 1:(size(icActivity, 2) - maxWaveletLength + 1)
                powerAtFreqId(waveletNumber, frame) = abs( icActivity(icId,frame:frame + length(wavelet{waveletNumber})-1) * wavelet{waveletNumber}') ^ 2;
            end;
        end;
        
        icCircularBuffer(icId) = circular_buffer_add(icCircularBuffer(icId), powerAtFreqId);
        meanIcPower(icId,:) = mean(icCircularBuffer(icId).buffer, 2);
    end;
    
   
    templateActivation = meanIcPower * imTemplate';
    
    meanPastActivations = sumPower / numberOfFramesInSum;
    stdPastActivation = (((sumPower2 / numberOfFramesInSum)  - (meanPastActivations.^2)) * numberOfFramesInSum / (numberOfFramesInSum-1)) .^ 0.5;
    
    if ~any(isnan(templateActivation))
        templateActivation;
        numberOfFramesInSum = numberOfFramesInSum + 1;
        sumPower  = sumPower + templateActivation;
        sumPower2 = sumPower2 + (templateActivation .^2);
    end;
    
    normalizedImTemplateActivation = (templateActivation - meanPastActivations) ./ stdPastActivation;
    
    if numberOfFramesInSum > 10
        %bar(axisHandle, 1:length(normalizedImTemplateActivation), normalizedImTemplateActivation);
        if any(ishandle(barHandle))
            for i=1:length(icIds)
                for templateId = 1:size(imTemplate, 1)
                    a = get(barHandle(i),'zdata');
                    a((2:3)+6*(templateId-1),2:3) = normalizedImTemplateActivation(i, templateId);
                    set(barHandle(i),'zdata', a);
                end;
            end;
            
        else
            barHandle = bar3(axisHandle,normalizedImTemplateActivation');
        end;
        zlim([-5 5]);
        drawnow;
    end;
    
    lastCalculatedLatency = mr.numberOfFramesReceived;
    
    %     sumOfpower = powerAtBand(mr.eeg.accumulatedIcActivity(:,(end-maxWaveletLength+1):end), wavelet);
    %
    %     % sumOfpower = mr.eeg.accumulatedIcActivity(:,end);
    %
    %     totalDipoleProjection = 0;
    %     for i=1:size(fsfVertextDistanceToDipole, 1)
    %         %activityToPlot = mr.eeg.accumulatedIcActivity(i,:);
    %         totalDipoleProjection =  totalDipoleProjection +sumOfpower(i) .* dipoleProjectionOnAllCortext(i,:);
    %     end;
    %
    %     %lastMin = (lastMin * numberOfRunsSofar + min(totalDipoleProjection(:))) / (numberOfRunsSofar+1);
    %     lastMax = (lastMax * numberOfRunsSofar + max(totalDipoleProjection(:))) / (numberOfRunsSofar+1);
    %     numberOfRunsSofar = numberOfRunsSofar + 1;
    %
    %
    %     if colorMapIsHasNegative
    %         maxAbsProjection = max(abs(totalDipoleProjection));
    %         adjustedTotalDipoleProjectionOverAllFrames = 0.5 * totalDipoleProjection / maxAbsProjection; % map the max value to 0.5
    %         colorValue =  (adjustedTotalDipoleProjectionOverAllFrames+ 0.5) * (numberOfColorsInTheColormap);
    %     else
    %         adjustedTotalDipoleProjectionOverAllFrames = totalDipoleProjection / lastMax;
    %         adjustedTotalDipoleProjectionOverAllFrames(adjustedTotalDipoleProjectionOverAllFrames>1) = 1;
    %         colorValue =  adjustedTotalDipoleProjectionOverAllFrames * (numberOfColorsInTheColormap);
    %     end;
    %
    %
    %     set(fsfHandle, 'Cdata', colorValue);
    
end;
end